# Generated by Django 3.2.2 on 2021-05-11 05:59

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_q", "0013_task_attempt_count"),
    ]

    operations = [
        migrations.AddField(
            model_name="schedule",
            name="cluster",
            field=models.CharField(blank=True, default=None, max_length=100, null=True),
        ),
    ]



import calendar
import inspect
from datetime import date, datetime

import django
from django import db
from django.conf import settings
from django.utils import timezone

from django_q.conf import Conf, logger

if django.VERSION < (4, 0):
    # pytz is the default in django 3.2. Remove when no support for 3.2
    from pytz import timezone as ZoneInfo
else:
    try:
        from zoneinfo import ZoneInfo
    except ImportError:
        from backports.zoneinfo import ZoneInfo


# credits: https://stackoverflow.com/a/4131114
# Made them aware of timezone
def add_months(d, months):
    month = d.month - 1 + months
    year = d.year + month // 12
    month = month % 12 + 1
    day = min(d.day, calendar.monthrange(year, month)[1])
    return d.replace(year=year, month=month, day=day)


# credits: https://stackoverflow.com/a/15743908
# Changed the last line to make it a little easier to read and changed it to move
# February 29 to 28 next year.
def add_years(d, years):
    """Return a date that's `years` years after the date (or datetime)
    object `d`. Return the same calendar date (month and day) in the
    destination year, if it exists, otherwise use the previous day
    (thus changing February 29 to February 28).
    """
    try:
        return d.replace(year=d.year + years)
    except ValueError:
        new_date = d + (date(d.year + years, 3, 1) - date(d.year, 3, 1))
        return d.replace(year=new_date.year, month=new_date.month, day=new_date.day)


def get_func_repr(func):
    # convert func to string
    if inspect.isfunction(func):
        return f"{func.__module__}.{func.__name__}"
    elif inspect.ismethod(func) and hasattr(func.__self__, "__name__"):
        return (
            f"{func.__self__.__module__}." f"{func.__self__.__name__}.{func.__name__}"
        )
    else:
        return str(func) if func else None


def localtime(value=None) -> datetime:
    """Override for timezone.localtime to deal with naive times and local times"""
    if settings.USE_TZ:
        if django.VERSION >= (4, 0) and getattr(settings, "USE_DEPRECATED_PYTZ", False):
            import pytz

            convert_to_tz = pytz.timezone(Conf.TIME_ZONE)
        else:
            convert_to_tz = ZoneInfo(Conf.TIME_ZONE)

        return timezone.localtime(value=value, timezone=convert_to_tz)
    if value is None:
        return datetime.now()
    else:
        return value


def close_old_django_connections():
    """
    Close django connections unless running with sync=True.
    """
    if Conf.SYNC:
        logger.warning(
            "Preserving django database connections because sync=True. Beware "
            "that tasks are now injected in the calling context/transactions "
            "which may result in unexpected behaviour."
        )
    else:
        db.close_old_connections()



import os

from django.core.management.base import BaseCommand
from django.utils.translation import gettext as _

from django_q.cluster import Cluster


class Command(BaseCommand):
    # Translators: help text for qcluster management command
    help = _("Starts a Django Q Cluster.")

    def add_arguments(self, parser):
        parser.add_argument(
            "--run-once",
            action="store_true",
            dest="run_once",
            default=False,
            help="Run once and then stop.",
        )
        parser.add_argument(
            "-n",
            "--name",
            dest="cluster_name",
            default=None,
            help="Set alternative cluster name instead of the name in Q_CLUSTER settings (for multi-queue setup). "
            "On Linux you should set name through `Q_CLUSTER_NAME=cluster_name python manage.py qcluster` instead.",
        )

    def handle(self, *args, **options):
        # Set alternative cluster_name before creating the cluster (cluster_name is broker's queue_name, too)
        cluster_name = options.get("cluster_name")
        if cluster_name:
            os.environ["Q_CLUSTER_NAME"] = cluster_name

        q = Cluster()
        q.start()
        if options.get("run_once", False):
            q.stop()



# Generated by Django 3.0.7 on 2020-08-11 15:17

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_q", "0012_auto_20200702_1608"),
    ]

    operations = [
        migrations.AddField(
            model_name="task",
            name="attempt_count",
            field=models.IntegerField(default=0),
        ),
    ]



# Generated by Django 3.0.8 on 2020-07-02 16:08

from django.db import migrations, models

import django_q.models


class Migration(migrations.Migration):
    dependencies = [
        ("django_q", "0011_auto_20200628_1055"),
    ]

    operations = [
        migrations.AlterField(
            model_name="schedule",
            name="cron",
            field=models.CharField(
                blank=True,
                help_text="Cron expression",
                max_length=100,
                null=True,
                validators=[django_q.models.validate_cron],
            ),
        ),
    ]



from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_q", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="schedule",
            name="args",
            field=models.TextField(
                help_text="e.g. 1, 2, 'John'", blank=True, null=True
            ),
        ),
        migrations.AlterField(
            model_name="schedule",
            name="kwargs",
            field=models.TextField(
                help_text="e.g. x=1, y=2, name='John'", blank=True, null=True
            ),
        ),
    ]
